@@ -223,7 +223,7 @@ static GDBM_FILE open_database(const char *domain,
     
     dbp = gdbm_open(buf, 0, O_RDONLY, 0, NULL);
 
-    if (debug_flag && dbp == NULL)
+    if (debug_flag > 1 && dbp == NULL)
 	Gperror("gdbm_open()");
     
     return dbp;
@@ -748,7 +748,10 @@ void *ypproc_clear_2_svc(void *dummy,
 static int ypall_close(void *data)
 {
     if (debug_flag && data == NULL)
+    {
 	fprintf(stderr, "ypall_close() called with NULL pointer.\n");
+	return 0;
+    }
 	    
     gdbm_close((GDBM_FILE) data);
     return 0;
